# Quickstart Guide

You will need:

- `python` 3.8 or greater: [https://www.python.org/downloads/](https://www.python.org/downloads/)


*Grid Pooler* is part of the `autora-core` package and does not need to be installed separately

you can import the grid pooler via:

```python
from autora.experimentalist.grid import grid_pool
```
